summaryrefslogtreecommitdiff
path: root/include/power-domain-uclass.h
diff options
context:
space:
mode:
authorSimon Glass <sjg@chromium.org>2020-02-03 07:35:51 -0700
committerSimon Glass <sjg@chromium.org>2020-02-05 19:33:46 -0700
commit4f51188e47921b17e6b3ce9606c8e71234c9f2df (patch)
treeb7660b22df03354bb3c1c6812abf3e5f4b22da14 /include/power-domain-uclass.h
parentcc92c3cc68a9053f53b2814e9233d86553cc998e (diff)
power-domain: Rename free() to rfree()
This function name conflicts with our desire to #define free() to something else on sandbox. Since it deals with resources, rename it to rfree(). Signed-off-by: Simon Glass <sjg@chromium.org> Reviewed-by: Anatolij Gustschin <agust@denx.de>
Diffstat (limited to 'include/power-domain-uclass.h')
-rw-r--r--include/power-domain-uclass.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/power-domain-uclass.h b/include/power-domain-uclass.h
index bd9906b2e7..acf749b38e 100644
--- a/include/power-domain-uclass.h
+++ b/include/power-domain-uclass.h
@@ -54,14 +54,14 @@ struct power_domain_ops {
*/
int (*request)(struct power_domain *power_domain);
/**
* free - Free a previously requested power domain.
*
* This is the implementation of the client power_domain_free() API.
*
* @power_domain: The power domain to free.
* @return 0 if OK, or a negative error code.
*/
- int (*free)(struct power_domain *power_domain);
+ int (*rfree)(struct power_domain *power_domain);
/**
* on - Power on a power domain.
*
@@ -54,14 +54,14 @@ struct power_domain_ops {
int (*request)(struct power_domain *power_domain);
/**
- * free - Free a previously requested power domain.
+ * rfree - Free a previously requested power domain.
*
* This is the implementation of the client power_domain_free() API.